@@ -1,23 +1,23 @@
 import grequests
 import time
 
-def singleRequests(url):
+def get_single_request(url,headers={}):
     urls = [url]
-    rs = (grequests.get(u, stream=False) for u in urls)
+    rs = (grequests.get(u,headers=headers, stream=False) for u in urls)
     response = grequests.map(rs)
     return response[0]
 
-def getAsyncRequests(urls,maxConnections,timeDelay,headers):
+def get_async_requests(urls,max_connections,time_delay,headers={}):
     startTime = time.time()
     pageCount = len(urls)
     print("Total web page count:", pageCount)
     responseSuccesCount = 0
     responseFailCount = 0
     responses = []
-    for x in range(0, pageCount+1, maxConnections):
+    for x in range(0, pageCount+1, max_connections):
         rs = (grequests.get(u, headers=headers, stream=False)
-            for u in urls[x:x+maxConnections])
-        time.sleep(timeDelay)
+            for u in urls[x:x+max_connections])
+        time.sleep(time_delay)
         responses.extend(grequests.map(rs))
         print(x, "Waiting")
 
